==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Input/aac/translations/aac_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>AACMetaDataModel</name>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="43"/>
        <source>Length</source>
        <translation>Duración</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="45"/>
        <source>Sample rate</source>
        <translation>Frecuencia</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="45"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="47"/>
        <source>Bitrate</source>
        <translation>Tasa de bits</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="47"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="48"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="49"/>
        <source>File size</source>
        <translation>Tamaño del archivo</translation>
    </message>
</context>
<context>
    <name>DecoderAACFactory</name>
    <message>
        <location filename="../decoderaacfactory.cpp" line="45"/>
        <source>AAC Plugin</source>
        <translation>Módulo AAC</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="47"/>
        <source>AAC Files</source>
        <translation>Archivos AAC</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="87"/>
        <source>About AAC Audio Plugin</source>
        <translation>Acerca del módulo de sonido AAC</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="88"/>
        <source>Qmmp AAC Audio Plugin</source>
        <translation>Módulo de sonido AAC para Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="89"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Input/aac/translations/aac_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>AACMetaDataModel</name>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="43"/>
        <source>Length</source>
        <translation>Duración</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="45"/>
        <source>Sample rate</source>
        <translation>Frecuencia</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="45"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="47"/>
        <source>Bitrate</source>
        <translation>Tasa de bits</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="47"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="48"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="49"/>
        <source>File size</source>
        <translation>Tamaño del archivo</translation>
    </message>
</context>
<context>
    <name>DecoderAACFactory</name>
    <message>
        <location filename="../decoderaacfactory.cpp" line="47"/>
        <source>AAC Plugin</source>
        <translation>Módulo AAC</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="49"/>
        <source>AAC Files</source>
        <translation>Archivos AAC</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="89"/>
        <source>About AAC Audio Plugin</source>
        <translation>Acerca del módulo de sonido AAC</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="90"/>
        <source>Qmmp AAC Audio Plugin</source>
        <translation>Módulo de sonido AAC para Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="91"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
